# #!/usr/bin/python3
# # -*- coding: utf-8 -*-


WANG_DEFAULT_CONFIG = {

    'menus': ['head', 'bold', 'fontSize', 'fontName', 'italic', 'underline', 'strikeThrough', 'foreColor', 'backColor',
              'link', 'list', 'justify', 'quote', 'emoticon', 'image', 'table', 'video', 'code', 'undo', 'redo'],
    'pasteFilterStyle': True,  # 是否关闭粘贴样式的过滤
    'pasteIgnoreImg': False,  # 是否忽略粘贴内容中的图片
    'colors': [
        '#000000',
        '#eeece0',
        '#1c487f',
        '#4d80bf',
        '#c24f4a',
        '#8baa4a',
        '#7b5ba1',
        '#46acc8',
        '#f9963b',
        '#ffffff'],  # 自定义配置颜色（字体颜色、背景色）可以添加更多的色号
}
